import Operis{{ model.plural }}Route from "{{ember_app_name}}/routes/operis/operis-{{ model.plural_converted }}";

var {{ model.plural }}Route = Operis{{ model.plural }}Route.extend({});

export default {{ model.plural }}Route;
