import Operis{{ model.plural }}Controller from '{{ember_app_name}}/controllers/operis/operis-{{ model.plural_converted }}';

var {{ model.plural }}Controller = Operis{{ model.plural }}Controller.extend({});

export default {{ model.plural }}Controller;  