import Operis{{ model.singular }}Route from "{{ember_app_name}}/routes/operis/operis-{{ model.singular_converted }}";
                                
var {{ model.singular }}Route = Operis{{ model.singular }}Route.extend({});

export default {{ model.singular }}Route;
