{{# if showPagination}}
    <ul class="pagination pagination-centered">
      <li {{bind-attr class="hasPrevious::disabled"}}>
        <a {{action goToPreviousPage}}>&laquo;</a>
      </li>
      {{#if showBeforeEllipsis}}
        {{pagination-page item=item qs=qs page_number=1 page=page}}
        <li class="disabled"><a>&hellip;</a></li>
      {{/if}}
      {{#each page_number in visiblePages}}
        {{pagination-page item=item qs=qs page_number=page_number page=page}}
      {{/each}}
      {{#if showAfterEllipsis}}
        <li class="disabled"><a>&hellip;</a></li>
        {{pagination-page item=item qs=qs page_number=page_number page=page}}
      {{/if}}
      <li {{bind-attr class="hasNext::disabled"}}>
        <a {{action goToNextPage}}>
          &raquo;
        </a>
    </ul>
{{/if}}